@@ -1,4 +1,4 @@
-/*	$Id: lowdown.h,v 1.41 2017/09/04 16:38:07 kristaps Exp $ */
+/*	$Id: lowdown.h,v 1.46 2017/10/08 16:38:52 kristaps Exp $ */
 /*
  * Copyright (c) 2017 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -138,22 +138,30 @@ struct	lowdown_meta {
 	char		*value;
 };
 
+enum	lowdown_chng {
+	LOWDOWN_CHNG_NONE = 0,
+	LOWDOWN_CHNG_INSERT,
+	LOWDOWN_CHNG_DELETE,
+};
+
 /*
  * Node parsed from input document.
  * Each node is part of the parse tree.
  */
 struct	lowdown_node {
 	enum lowdown_rndrt	 type;
+	enum lowdown_chng	 chng; /* change type */
+	size_t			 id; /* unique identifier */
 	union {
 		struct rndr_doc_header {
 			struct lowdown_meta *m; /* unescaped */
 			size_t msz;
 		} rndr_doc_header;
 		struct rndr_list {
-			enum hlist_fl flags;
+			enum hlist_fl flags; /* only HLIST_FL_ORDERED */
 		} rndr_list; 
 		struct rndr_listitem {
-			enum hlist_fl flags; /* see rndr_list */
+			enum hlist_fl flags; /* all possible flags */
 			size_t num; /* index in ordered */
 		} rndr_listitem; 
 		struct rndr_header {
@@ -237,10 +245,10 @@ struct	lowdown_opts {
 #define LOWDOWN_SUPER		 0x100
 #define LOWDOWN_MATH		 0x200
 #define LOWDOWN_NOINTEM		 0x400
-#define LOWDOWN_SPHD		 0x800
 #define LOWDOWN_MATHEXP		 0x1000
 #define LOWDOWN_NOCODEIND	 0x2000
 #define	LOWDOWN_METADATA	 0x4000
+#define	LOWDOWN_COMMONMARK	 0x8000
 	unsigned int		 oflags;
 #define LOWDOWN_HTML_SKIP_HTML	 0x01
 #define LOWDOWN_HTML_ESCAPE	 0x02
@@ -271,9 +279,17 @@ void	 lowdown_buf(const struct lowdown_opts *,
 		const char *, size_t,
 		char **, size_t *,
 		struct lowdown_meta **, size_t *);
+void	 lowdown_buf_diff(const struct lowdown_opts *, 
+		const char *, size_t,
+		const struct lowdown_opts *,
+		const char *, size_t,
+		char **, size_t *);
 int	 lowdown_file(const struct lowdown_opts *, 
 		FILE *, char **, size_t *,
 		struct lowdown_meta **, size_t *);
+int	 lowdown_file_diff(const struct lowdown_opts *, FILE *, 
+		const struct lowdown_opts *, FILE *,
+		char **, size_t *);
 
 /* 
  * Low-level functions.
@@ -285,6 +301,9 @@ hdoc 	*lowdown_doc_new(const struct lowdown_opts *);
 struct lowdown_node
 	*lowdown_doc_parse(hdoc *, const char *, size_t, 
 		struct lowdown_meta **, size_t *);
+struct lowdown_node
+	*lowdown_diff(const struct lowdown_node *,
+		const struct lowdown_node *);
 void	 lowdown_doc_free(hdoc *);
 
 void 	 lowdown_node_free(struct lowdown_node *);
